# weavedoc

weavedoc is a commandline tool to create, manage, view, and publish documents in markdown format. Key idea is to weave various kinds of context information taken from additional files into a markdown document to enrich a document. Context includes well known types such as audio, images, videos, and other kinds of objects such as maps. 

Weavedoc can serve as a frontend to pandoc. That is, enhanced documents can be further processed pandoc. Pandoc can also be used is a HTML generator when viewing a document using a bowser. In case you may use pandoc markdown. 
